@@ -3,7 +3,6 @@ from __future__ import annotations
 import argparse
 from typing import Any
 
-import django
 from django.core.management import BaseCommand, CommandError
 from django.db import DEFAULT_DB_ALIAS, connections
 from django.db.utils import ConnectionDoesNotExist
@@ -21,11 +20,7 @@ class Command(BaseCommand):
         "'{default}'."
     ).format(default=DEFAULT_DB_ALIAS)
 
-    requires_system_checks: list[str] | bool
-    if django.VERSION >= (3, 2):
-        requires_system_checks = []
-    else:
-        requires_system_checks = False
+    requires_system_checks: list[str] = []
 
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
         parser.add_argument(
